<?php
/**
 * Author: Patryk Gorol
 * Class: cssAttacher
 * File: cssAttacher.php
 *
 */

class cssAttacher
{
    /**
     * Key in params
     * Yii::app()->params[key]
     * @var string
     */
    protected static $key = 'cssattacher';

    /**
     * Refresh css every time page refresh
     * Use false when in production
     * @var bool
     */
    protected static $alwaysRefresh = true;

    /**
     * Join styles and register CSS file
     * @throws cssAttachException
     * @return bool
     */
    public static function renderStyles()
    {
        if (!isset(Yii::app()->params[self::$key])) {
            return false;
        }

        //get styles
        $register = Yii::app()->params[self::$key];

        sort($register);

        //name of file
        $name = md5(implode('', array_keys($register)));

        //assets script directory
        $file_dir = dirname(Yii::app()->request->scriptFile) . DIRECTORY_SEPARATOR . 'assets' . DIRECTORY_SEPARATOR . $name . '.css';

        //css file
        $file_url = Yii::app()->baseUrl . '/assets/' . $name . '.css';

        if (file_exists($file_dir) && self::$alwaysRefresh === false) {
            Yii::app()->clientScript->registerCssFile($file_url);
            return true;
        }

        //join into new style string
        $style_string = '';

        foreach ($register as $element => $styles) {
            $style_string .= $element . '{';
            foreach ($styles as $selector => $value) {
                $style_string .= $selector . ':' . $value . '; ';
            }
            $style_string .= '} ';
        }

        //save and register css
        if(file_put_contents($file_dir, $style_string) == false)
            throw new cssAttachException('Cannot save css file '.$file_dir.'. Check directory permissions.');


        Yii::app()->clientScript->registerCssFile($file_url);

        return true;
    }

    /**
     * Attatch styles to global array
     *
     * @param array $css_array
     * @return bool
     * @throws cssAttachException
     */
    public static function attach($css_array = array())
    {
        if (!is_array($css_array)) {
            throw new cssAttachException('Expected argument of type array, '.gettype($css_array).' given.');
        }

        //add or init style
        if (!isset(Yii::app()->params[self::$key])) {
            Yii::app()->setParams(array(self::$key => $css_array));
        } else {
            $old = Yii::app()->params[self::$key];

            Yii::app()->params[self::$key] = array_merge($old, $css_array);;
        }

        return true;
    }


}

class cssAttachException extends Exception{}